/**
 * Copyright (c) 2011-2012 EBMWebsourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.component.framework.logger;

import javax.jbi.messaging.MessageExchange;

import org.ow2.petals.commons.log.TraceCode;

/**
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public class ProvideFlowStepBeginLogData extends AbstractFlowLogData {

    private static final long serialVersionUID = -874146283132129163L;

    /**
     * @param flowInstanceId
     *            The flow instance identifier with which this MONIT trace must be logged
     * @param flowStepId
     *            The flow step identifier with which this MONIT trace must be logged
     * @param flowStepInterfaceName
     *            Interface name of the service provider
     * @param flowStepServiceName
     *            Service name of the service provider
     * @param flowStepOperationName
     *            operation name of the service provider
     * @param flowStepEndpointName
     *            Endpoint name of the service provider
     */
    public ProvideFlowStepBeginLogData(final String flowInstanceId, final String flowStepId,
            final String flowStepInterfaceName, final String flowStepServiceName, final String flowStepOperationName,
            final String flowStepEndpointName, final String flowPreviousStepId, final MessageExchange exchange) {
        super(TraceCode.PROVIDE_FLOW_STEP_BEGIN, flowInstanceId, flowStepId);
        putData(FLOW_STEP_INTERFACE_NAME_PROPERTY_NAME, flowStepInterfaceName);
        putData(FLOW_STEP_SERVICE_NAME_PROPERTY_NAME, flowStepServiceName);
        putData(FLOW_STEP_OPERATION_NAME_PROPERTY_NAME, flowStepOperationName);
        putData(FLOW_STEP_ENDPOINT_NAME_PROPERTY_NAME, flowStepEndpointName);
        putData(FLOW_PREVIOUS_STEP_ID_PROPERTY_NAME, flowPreviousStepId);
        putData(FLOW_EXCHANGE_PROPERTY_NAME, exchange);
    }
}
